@@ -55,7 +55,7 @@ def loggerDecorator(outputString, args_print = []):
                 logging.error(errorInfo)
 
                 # 例外スロー
-                raise Exception
+                raise 
             
             return ret
 
