@@ -756,7 +756,7 @@ class recset(Generic[T]):
             # 戻り値を返す
             return True if len(dfCheck) > 0 or len(q) > 0 else False
 
-    def existsPKeyRec(self, row):
+    def existsPKeyRec(self, row, sessionCheck = False):
         
         """
         対象行に対して主キー制約に違反しているか
@@ -768,7 +768,8 @@ class recset(Generic[T]):
         """
 
         # セッションチェック
-        self.__checkSessionOpen(False, False)
+        if sessionCheck:
+            self.__checkSessionOpen(False, False)
         
         # 主キーを条件として該当レコードが存在するか確認
         w = self.__getPKeyFilter_sa(row)
@@ -785,7 +786,8 @@ class recset(Generic[T]):
             self.rows.remove(row)
 
         # セッションチェック
-        self.__checkSessionClose()
+        if sessionCheck:
+            self.__checkSessionClose()
 
         # 結果を返す
         return len(q) > 0
